@@ -15,8 +15,8 @@
 
     You should have received a copy of the GNU Library General Public License
     along with this library; see the file COPYING.LIB.  If not, write to
-    the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-    Boston, MA 02111-1307, USA.
+    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+    Boston, MA 02110-1301, USA.
 
     Author: Radek Doulik
 
@@ -25,6 +25,7 @@
 #ifndef EDITOR_CONTROL_FACTORY_H_
 #define EDITOR_CONTROL_FACTORY_H_
 
+#include <config.h>
 #include <bonobo.h>
 
 #define CONTROL_FACTORY_ID "OAFIID:GNOME_GtkHTML_Editor_Factory:" EDITOR_API_VERSION
