@@ -17,8 +17,8 @@
 
     You should have received a copy of the GNU Library General Public License
     along with this library; see the file COPYING.LIB.  If not, write to
-    the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-    Boston, MA 02111-1307, USA.
+    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+    Boston, MA 02110-1301, USA.
 */
 
 #include <config.h>
@@ -120,6 +120,7 @@ destroy (HTMLObject *o)
 			gtk_container_remove (GTK_CONTAINER (element->parent), element->widget);
 		} else {
 			g_object_ref_sink (element->widget);
+			g_object_unref (element->widget);
 		}
 	}
 
