@@ -17,8 +17,8 @@
    
    You should have received a copy of the GNU Library General Public License
    along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-   Boston, MA 02111-1307, USA.
+   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+   Boston, MA 02110-1301, USA.
 */
 
 #ifndef _HTMLENGINE_H_
@@ -65,6 +65,7 @@ struct _HTMLEngine {
 	GdkGC *invert_gc;
 
 	gboolean editable;
+	gboolean caret_mode;
 
 	HTMLObject *clipboard;
 	guint       clipboard_len;
@@ -85,7 +86,7 @@ struct _HTMLEngine {
 	gboolean parsing;
 	HTMLTokenizer *ht;
 	HTMLStringTokenizer *st;
-	HTMLObject *clue;
+	HTMLObject *clue;         /* the document root */
 	
 	HTMLObject *flow;
 
@@ -101,9 +102,6 @@ struct _HTMLEngine {
 	gint width;
 	gint height;
 
-	HTMLHAlignType divAlign;
-	HTMLHAlignType pAlign;
-
 	/* Number of tokens parsed in the current time-slice */
 	gint parseCount;
 	gint granularity;
@@ -124,12 +122,11 @@ struct _HTMLEngine {
 	HTMLStack *clueflow_style_stack; /* Clueflow style stack, elements are HTMLClueFlowStyles.  */
 	HTMLStack *frame_stack;
 	HTMLStack *body_stack;
+	HTMLStack *table_stack;
 
 	gchar *url;
 	gchar *target;
 
-	HTMLBlockStackElement *blockStack;
-
 	/* timer id to schedule paint events */
 	guint updateTimer;
 
@@ -179,13 +176,6 @@ struct _HTMLEngine {
            their own.  */
 	gboolean avoid_para;
 
-	/* This is TRUE if we want a paragraph break to be inserted before the
-           next element.  */
-	gboolean pending_para;
-
-	/* Alignment for the pending paragraph we are going to insert.  */
-	HTMLHAlignType pending_para_alignment;
-
 	/* Whether we have the keyboard focus.  */
 	guint have_focus : 1;
 
@@ -262,15 +252,21 @@ struct _HTMLEngine {
 	GList *cut_and_paste_stack;
 
 	gboolean block;
+	gboolean block_images;
 	gint opened_streams;
+	gboolean stopped;
+	gboolean keep_scroll;
 
 	HTMLObject *focus_object;
+	gint focus_object_offset;
 
 	gboolean save_data;
 	gint saved_step_count;
 
 	gboolean expose;
 	gboolean need_update;
+
+	HTMLObject *parser_clue;  /* the root of the currently parsed block */
 };
 
 /* must be forward referenced *sigh* */
@@ -319,6 +315,8 @@ GtkHTMLStream *html_engine_begin            (HTMLEngine  *p,
 					     char        *content_type);
 void           html_engine_parse            (HTMLEngine  *p);
 void           html_engine_stop_parser      (HTMLEngine  *e);
+void           html_engine_stop             (HTMLEngine  *e);
+void           html_engine_flush            (HTMLEngine  *e);
 
 /* Rendering control.  */
 gint  html_engine_calc_min_width       (HTMLEngine *e);
@@ -408,7 +406,7 @@ void      html_engine_replace                   (HTMLEngine *e,
 						 gboolean forward,
 						 gboolean regular,
 						 void (*ask)(HTMLEngine *, gpointer), gpointer ask_data);
-void      html_engine_replace_do                (HTMLEngine *e, HTMLReplaceQueryAnswer answer);
+gboolean  html_engine_replace_do                (HTMLEngine *e, HTMLReplaceQueryAnswer answer);
 gint      html_engine_replaced                  (void);
 
 /* Magic links */
@@ -468,10 +466,14 @@ void html_engine_redraw_selection (HTMLEngine *e);
 
 gboolean    html_engine_focus              (HTMLEngine       *e,
 					    GtkDirectionType  dir);
-HTMLObject *html_engine_get_focus_object   (HTMLEngine       *e);
+HTMLObject *html_engine_get_focus_object   (HTMLEngine       *e,
+					    gint             *offset);
 void        html_engine_set_focus_object   (HTMLEngine       *e,
-					    HTMLObject       *o);
-void        html_engine_draw_focus_object  (HTMLEngine       *e);
+					    HTMLObject       *o,
+					    gint              offset);
+void        html_engine_update_focus_if_necessary (HTMLEngine	*e, 
+						   HTMLObject	*o,
+						   gint		offset);
 
 HTMLMap *html_engine_get_map  (HTMLEngine  *e,
 			       const gchar *name);
@@ -480,4 +482,16 @@ gboolean html_engine_selection_contains_object_type (HTMLEngine *e,
 						     HTMLType obj_type);
 gboolean html_engine_selection_contains_link        (HTMLEngine *e);
 
+gint  html_engine_get_left_border    (HTMLEngine *e);
+gint  html_engine_get_right_border   (HTMLEngine *e);
+gint  html_engine_get_top_border     (HTMLEngine *e);
+gint  html_engine_get_bottom_border  (HTMLEngine *e);
+
+HTMLImageFactory *html_engine_get_image_factory (HTMLEngine *e);
+void html_engine_opened_streams_increment (HTMLEngine *e);
+void html_engine_opened_streams_decrement (HTMLEngine *e);
+void html_engine_opened_streams_set (HTMLEngine *e, int value);
+
+void html_engine_refresh_fonts (HTMLEngine *e);
+
 #endif /* _HTMLENGINE_H_ */
