@@ -17,8 +17,8 @@
 
    You should have received a copy of the GNU Library General Public License
    along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-   Boston, MA 02111-1307, USA.
+   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+   Boston, MA 02110-1301, USA.
 */
 
 #ifndef _HTMLOBJECT_H_
@@ -261,12 +261,20 @@ struct _HTMLObjectClass {
 	gint (* get_child_index)         (HTMLObject *self, HTMLObject *child);
 
 	HTMLDirection (*get_direction)   (HTMLObject *self);
+
+	gboolean (*cursor_forward)       (HTMLObject *self, HTMLCursor *cursor, HTMLEngine *engine);
+	gboolean (*cursor_backward)       (HTMLObject *self, HTMLCursor *cursor, HTMLEngine *engine);
+	gboolean (*cursor_right)         (HTMLObject *self, HTMLPainter *painter, HTMLCursor *cursor);
+	gboolean (*cursor_left)          (HTMLObject *self, HTMLPainter *painter, HTMLCursor *cursor);
+
+	int (*get_right_edge_offset) (HTMLObject *o, HTMLPainter *painter, int offset);
+	int (*get_left_edge_offset) (HTMLObject *o, HTMLPainter *painter, int offset);
+
+	gboolean (*backspace)       (HTMLObject *self, HTMLCursor *cursor, HTMLEngine *engine);
 };
 
-
 extern HTMLObjectClass html_object_class;
 
-
 /* Basics.  */
 void            html_object_type_init             (void);
 void            html_object_init                  (HTMLObject            *self,
@@ -390,6 +398,9 @@ gint            html_object_calc_preferred_width  (HTMLObject            *o,
 void            html_object_calc_abs_position     (HTMLObject            *o,
 						   gint                  *x_return,
 						   gint                  *y_return);
+void            html_object_calc_abs_position_in_frame (HTMLObject       *o,
+							int              *x_return,
+							int              *y_return);
 gboolean        html_object_intersect             (HTMLObject            *o,
 					           GdkRectangle          *intersection,
 					           gint                   x,
@@ -452,9 +463,20 @@ HTMLObject     *html_object_check_point           (HTMLObject            *clue,
 /* Movement functions */
 /* move cursor in scope of object */
 gboolean        html_object_cursor_forward        (HTMLObject            *self,
-						   HTMLCursor            *cursor);
+						   HTMLCursor            *cursor,
+						   HTMLEngine            *engine);
 gboolean        html_object_cursor_backward       (HTMLObject            *self,
+						   HTMLCursor            *cursor,
+						   HTMLEngine            *engine);
+gboolean        html_object_cursor_left           (HTMLObject            *self,
+						   HTMLPainter           *painter,
 						   HTMLCursor            *cursor);
+gboolean        html_object_cursor_right          (HTMLObject            *self,
+						   HTMLPainter           *painter,
+						   HTMLCursor            *cursor);
+gboolean        html_object_backspace             (HTMLObject            *self,
+						   HTMLCursor            *cursor,
+						   HTMLEngine            *engine);
 
 /* get prev/next object in scope of parent */
 HTMLObject     *html_object_next                  (HTMLObject            *self,
@@ -599,6 +621,13 @@ HTMLObject *html_object_next_cursor_leaf    (HTMLObject *o,
 HTMLObject *html_object_prev_cursor_leaf    (HTMLObject *o,
 					     HTMLEngine *e);
 
+int  html_object_get_right_edge_offset  (HTMLObject *o,
+					 HTMLPainter *painter,
+					 int offset);
+int  html_object_get_left_edge_offset   (HTMLObject *o,
+					 HTMLPainter *painter,
+					 int offset);
+
 const char *html_object_get_id  (HTMLObject *o);
 void        html_object_set_id  (HTMLObject *o,
 				 const char *id);
